@@ -22,7 +22,6 @@ from django.test import TestCase, Client
 from .models import R
 
 
-
 class TestR(TestCase):
     """Tests for the ``R`` class."""
 
@@ -66,7 +65,7 @@ class TestR(TestCase):
         slug = 'test-slug'
         expected_results = [
             "m:{0}:{1}".format(slug, d.strftime("%Y-%m-%d")),
-            "m:{0}:w:{1}".format(slug, d.strftime("%U")),
+            "m:{0}:w:{1}".format(slug, d.strftime("%Y-%U")),
             "m:{0}:m:{1}".format(slug, d.strftime("%Y-%m")),
             "m:{0}:y:{1}".format(slug, d.strftime("%Y")),
         ]
@@ -83,7 +82,7 @@ class TestR(TestCase):
         """Tests ``R._build_keys``. with a *weekly* granularity."""
         d = datetime.date(2012, 4, 1)  # April Fools!
         keys = self.r._build_keys('test-slug', date=d, granularity='weekly')
-        self.assertEqual(keys, ['m:test-slug:w:14'])
+        self.assertEqual(keys, ['m:test-slug:w:2012-14'])
 
     def test__build_keys_monthly(self):
         """Tests ``R._build_keys``. with a *monthly* granularity."""
@@ -388,19 +387,25 @@ class TestViews(TestCase):
         expected."""
         url = reverse('redis_metric_aggregate')
         with patch('redis_metrics.views.R'):
-            # Test with ONE metric selected
-            data = {'metrics': ['foo']}
-            resp = self.client.post(url, data)
-            self.assertEqual(resp.status_code, 302)
-            # make sure the metric slug shows up in the redirect URL
-            self.assertIn('foo', resp.get("Location", ''))
+            with patch('redis_metrics.forms.R') as mock_r:
+                # Set up a return value for ``R.metric_slugs``, which is used
+                # in the ``AggregateMetricForm``
+                r = mock_r.return_value  # An instance of our Mocked R class
+                r.metric_slugs.return_value = set(['test', 'foo', 'bar'])
 
-            # Test with TWO metrics selected
-            data = {'metrics': ['foo', 'bar']}
-            resp = self.client.post(url, data)
-            self.assertEqual(resp.status_code, 302)
-            # make sure the metric slug shows up in the redirect URL
-            self.assertIn('foo+bar', resp.get("Location", ''))
+                # Test with ONE metric selected
+                data = {'metrics': ['foo']}
+                resp = self.client.post(url, data)
+                self.assertEqual(resp.status_code, 302)
+                # make sure the metric slug shows up in the redirect URL
+                self.assertIn('foo', resp.get("Location", ''))
+
+                # Test with TWO metrics selected
+                data = {'metrics': ['foo', 'bar']}
+                resp = self.client.post(url, data)
+                self.assertEqual(resp.status_code, 302)
+                # make sure the metric slug shows up in the redirect URL
+                self.assertIn('foo+bar', resp.get("Location", ''))
 
     def test_aggregate_detail_view(self):
         """Tests ``views.AggregateDetailView``."""
@@ -443,7 +448,7 @@ class TestViews(TestCase):
             if granularity == "daily":
                 key_pattern = "m:{0}:2013-01-10"
             elif granularity == "weekly":
-                key_pattern = "m:{0}:w:01"
+                key_pattern = "m:{0}:w:2013-01"
             elif granularity == "monthly":
                 key_pattern = "m:{0}:m:2013-01"
             elif granularity == "yearly":
